@@ -26,6 +26,8 @@
 #include <Kirigami/Platform/PlatformTheme>
 #include <Kirigami/Platform/TabletModeWatcher>
 
+#include <numeric>
+
 std::unique_ptr<QStyle> KQuickStyleItem::s_style = nullptr;
 
 QStyle *KQuickStyleItem::style()
@@ -362,7 +364,7 @@ void KQuickStyleItem::initStyleOption()
             opt->toolButtonStyle = Qt::ToolButtonFollowStyle;
         }
 
-        const QFont font = qApp->font("QToolButton");
+        const QFont font = m_font.isCopyOf(qApp->font()) ? qApp->font("QToolButton") : m_font;
         opt->font = font;
         opt->fontMetrics = QFontMetrics(font);
         break;
@@ -903,12 +905,11 @@ void KQuickStyleItem::resolvePalette()
         return;
     }
 
-    const QVariant controlPalette = m_control ? m_control->property("palette") : QVariant();
-    if (controlPalette.isValid()) {
-        m_styleoption->palette = controlPalette.value<QPalette>();
-    } else {
-        m_styleoption->palette = m_theme->palette();
-    }
+    // In theory here we should conside  m_control->property("palette")
+    // Whether the client code did set a custom palette color, but we can't read and write it
+    // from c++ anymore as is not a QPalette but a wrapper type we don't have access to,
+    // this kind of binding will need to be done on QML side
+    m_styleoption->palette = m_theme->palette();
 }
 
 int KQuickStyleItem::topPadding() const
@@ -1036,13 +1037,8 @@ QString KQuickStyleItem::hitTest(int px, int py)
 
 QRect KQuickStyleItem::computeBoundingRect(const QList<QRect> &rects)
 {
-    QRegion r;
-
-    for (const auto& rect : rects) {
-        r = r.united(rect);
-    }
-
-    return r.boundingRect();
+    const auto region = std::accumulate(rects.begin(), rects.end(), QRegion());
+    return region.boundingRect();
 }
 
 QSize KQuickStyleItem::sizeFromContents(int width, int height)
@@ -1461,6 +1457,22 @@ void KQuickStyleItem::resetHints()
     m_hints.clear();
 }
 
+void KQuickStyleItem::setFont(const QFont &font)
+{
+    if (font == m_font) {
+        return;
+    }
+    m_font = font;
+    updateSizeHint();
+    polish();
+    Q_EMIT fontChanged();
+}
+
+void KQuickStyleItem::resetFont()
+{
+    setFont(qApp->font());
+}
+
 void KQuickStyleItem::setElementType(const QString &str)
 {
     if (m_type == str) {
